# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: trading_account/v1/cash_balance.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'trading_account/v1/cash_balance.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%trading_account/v1/cash_balance.proto\x12\x07trading\x1a\x1fgoogle/protobuf/timestamp.proto\"\xe2\x01\n\x19TradingAccountCashBalance\x12\x1a\n\x12trading_account_id\x18\x01 \x01(\t\x12\x0f\n\x07\x62\x61lance\x18\x02 \x01(\x01\x12(\n\x04\x64\x61te\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x14\n\x0crealized_pnl\x18\x04 \x01(\x01\x12)\n\x0b\x65nvironment\x18\x05 \x01(\x0e\x32\x14.trading.Environment\x12\x1d\n\x05stage\x18\x06 \x01(\x0e\x32\x0e.trading.Stage\x12\x0e\n\x06\x62roker\x18\x07 \x01(\t\"\xf0\x01\n\x1eTradingAccountCashBalanceEvent\x12&\n\nevent_type\x18\x01 \x01(\x0e\x32\x12.trading.EventType\x12(\n\x0b\x65ntity_type\x18\x02 \x01(\x0e\x32\x13.trading.EntityType\x12)\n\x0b\x65nvironment\x18\x03 \x01(\x0e\x32\x14.trading.Environment\x12\x1d\n\x05stage\x18\x04 \x01(\x0e\x32\x0e.trading.Stage\x12\x32\n\x06\x65ntity\x18\x05 \x01(\x0b\x32\".trading.TradingAccountCashBalance\"i\n TradingAccountCashBalanceMessage\x12\x36\n\x05\x65vent\x18\x01 \x01(\x0b\x32\'.trading.TradingAccountCashBalanceEvent\x12\r\n\x05topic\x18\x02 \x01(\t*V\n\x0b\x45nvironment\x12\x1b\n\x17\x45NVIRONMENT_UNSPECIFIED\x10\x00\x12\x14\n\x10\x45NVIRONMENT_DEMO\x10\x01\x12\x14\n\x10\x45NVIRONMENT_LIVE\x10\x02*4\n\x05Stage\x12\x15\n\x11STAGE_UNSPECIFIED\x10\x00\x12\x14\n\x10STAGE_EVALUATION\x10\x01*o\n\tEventType\x12\x1a\n\x16\x45VENT_TYPE_UNSPECIFIED\x10\x00\x12\x16\n\x12\x45VENT_TYPE_CREATED\x10\x01\x12\x16\n\x12\x45VENT_TYPE_UPDATED\x10\x02\x12\x16\n\x12\x45VENT_TYPE_DELETED\x10\x03*W\n\nEntityType\x12\x1b\n\x17\x45NTITY_TYPE_UNSPECIFIED\x10\x00\x12,\n(ENTITY_TYPE_TRADING_ACCOUNT_CASH_BALANCE\x10\x01\x42(Z&github.com/MyFunded/my-funded-grpc-apib\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'trading_account.v1.cash_balance_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z&github.com/MyFunded/my-funded-grpc-api'
  _globals['_ENVIRONMENT']._serialized_start=662
  _globals['_ENVIRONMENT']._serialized_end=748
  _globals['_STAGE']._serialized_start=750
  _globals['_STAGE']._serialized_end=802
  _globals['_EVENTTYPE']._serialized_start=804
  _globals['_EVENTTYPE']._serialized_end=915
  _globals['_ENTITYTYPE']._serialized_start=917
  _globals['_ENTITYTYPE']._serialized_end=1004
  _globals['_TRADINGACCOUNTCASHBALANCE']._serialized_start=84
  _globals['_TRADINGACCOUNTCASHBALANCE']._serialized_end=310
  _globals['_TRADINGACCOUNTCASHBALANCEEVENT']._serialized_start=313
  _globals['_TRADINGACCOUNTCASHBALANCEEVENT']._serialized_end=553
  _globals['_TRADINGACCOUNTCASHBALANCEMESSAGE']._serialized_start=555
  _globals['_TRADINGACCOUNTCASHBALANCEMESSAGE']._serialized_end=660
# @@protoc_insertion_point(module_scope)
